//
// Process the list of current highlight.js CSS files and places them
// in the `./lib/highlights dirctory.  An index.ts file is also created
// to "require" them.  This file is then used by markup.ts to
// pull in each of these files for webpack.
//
// The index.ts file contains an exported object named "cssHighlights"
// that contains a key for each CSS file and the associated ".style"
// file.  The markup processor can then present a list of all
// available CSS syntax highlighting schemes for the user to choose.
//
// A new method named "setHighligh(name: string)" is provided by
// Markup to set the current CSS scheme.  There is also a new
// property on the MarkupOptions.
//
'use strict';

const debug = require('debug')('buildStyles');
const fs = require('fs-extra');
const {join} = require('util.join');
const shell = require('shelljs');

console.log('Building CSS styles');

let src = join(process.cwd(), 'node_modules', 'highlight.js', 'styles');
let dst = join(process.cwd(), 'lib', 'highlights');

if (fs.existsSync(dst)) {
	shell.rm('-rf', dst);
}
shell.mkdir(dst);

let files = fs.readdirSync(src)
	.filter(file => fs.statSync(join(src, file)).isFile() && file.slice(-4) === '.css');

const styles = {};
const requires = [];

for (const file of files) {
	const filename = file.slice(0, file.length - 4);
	const sf = join(src, `${filename}.css`);
	const df = join(dst, `${filename}.style`);

	debug('copy file %s to %s', sf, df);
	shell.cp(sf, df);

	styles[filename] = `${filename}.style`;
	requires.push(`require('./${filename}.style');`);
}

const json = JSON.stringify(styles, null, '\t').replace(/\"/g, '\'');

let s = requires.join('\n');
s += '\n\n';
s += `export const cssHighlights: any = ${json};\n`;

fs.writeFileSync(join(dst, 'index.ts'), s);
